@@ -10,7 +10,6 @@ import (
 	"github.com/gin-gonic/gin"
 	"github.com/mattn/go-colorable"
 
-
 	"{{GOLANG_MODULE}}/internal/api"
 	"{{GOLANG_MODULE}}/internal/middleware"
 )
@@ -20,7 +19,7 @@ func Start(ctx context.Context, ch chan error) {
 	app := newApp()
 
 	// Register HTTP route handlers.
-	registerRoutes(app)
+	api.RegisterRoutes(app)
 
 	// Create new HTTP server instance.
 	server := &http.Server{
@@ -46,18 +45,6 @@ func Start(ctx context.Context, ch chan error) {
 	}
 }
 
-func registerRoutes(app *gin.Engine) {
-	router := app.Group(conf.BasePath())
-
-	api.RegisterUser(router)
-
-	api.GetAppDescription(router)
-
-	// For debug
-	api.RegisterExample(router)
-	api.RegisterSwagger(router)
-}
-
 func newApp() (app *gin.Engine) {
 	// Set HTTP server mode.
 	gin.SetMode(conf.HttpMode())
