@@ -1,4 +1,4 @@
-{{GOLANG_HEADER}}
+{{SLASH_COMMENTS}}
 
 #ifndef UNTITLED__WIDGET_H
 #define UNTITLED__WIDGET_H
