@@ -10,6 +10,7 @@ import click
 from click_aliases import ClickAliasedGroup
 
 from .auto_unzip import PASSWORDS_DIR, PASSWORDS_FILE, Unzipper
+from .version import __version__
 
 
 @click.group(cls=ClickAliasedGroup)
@@ -17,6 +18,11 @@ def command_ucmd():
     pass
 
 
+@command_ucmd.command()
+def version():
+    click.echo(__version__)
+
+
 @command_ucmd.command(
     aliases=["unzip", "uz"],
     context_settings={"help_option_names": ["-h", "--help"]},
